@@ -691,7 +691,7 @@ async def consumer(host: str,
                     sys.stdout.flush()
                     last_log = runtime
 
-                    if print_check < 10:
+                    if print_check > 10:
                         LOG.info("Events processed: {:,} at {:,.2f} events/sec".format(
                             lines_read, ln_sec))
                         print_log = runtime
