@@ -31,13 +31,11 @@ async def handle_req(reader: asyncio.StreamReader, writer: asyncio.StreamWriter,
         await reader.read(4026)
 
         while True:
-            line = fp_.read()
+            line = fp_.readline()
             if not line:
+                LOG.info("No remaining line...breaking...")
                 break
             writer.write(line)
-            check = await reader.read()
-            if check and check == -1:
-                break
         await writer.drain()
         writer.close()
         LOG.info("All lines sent...closing...")
